==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/emr/kotlin/outputs/InstanceFleetInstanceTypeConfig.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.emr.kotlin.outputs

import kotlin.Double
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property bidPrice The bid price for each EC2 Spot instance type as defined by `instance_type`. Expressed in USD. If neither `bid_price` nor `bid_price_as_percentage_of_on_demand_price` is provided, `bid_price_as_percentage_of_on_demand_price` defaults to 100%.
 * @property bidPriceAsPercentageOfOnDemandPrice The bid price, as a percentage of On-Demand price, for each EC2 Spot instance as defined by `instance_type`. Expressed as a number (for example, 20 specifies 20%). If neither `bid_price` nor `bid_price_as_percentage_of_on_demand_price` is provided, `bid_price_as_percentage_of_on_demand_price` defaults to 100%.
 * @property configurations A configuration classification that applies when provisioning cluster instances, which can include configurations for applications and software that run on the cluster. List of `configuration` blocks.
 * @property ebsConfigs Configuration block(s) for EBS volumes attached to each instance in the instance group. Detailed below.
 * @property instanceType An EC2 instance type, such as m4.xlarge.
 * @property weightedCapacity The number of units that a provisioned instance of this type provides toward fulfilling the target capacities defined in `aws.emr.InstanceFleet`.
 */
public data class InstanceFleetInstanceTypeConfig(
    public val bidPrice: String? = null,
    public val bidPriceAsPercentageOfOnDemandPrice: Double? = null,
    public val configurations: List<InstanceFleetInstanceTypeConfigConfiguration>? = null,
    public val ebsConfigs: List<InstanceFleetInstanceTypeConfigEbsConfig>? = null,
    public val instanceType: String,
    public val weightedCapacity: Int? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.emr.outputs.InstanceFleetInstanceTypeConfig):
            InstanceFleetInstanceTypeConfig = InstanceFleetInstanceTypeConfig(
            bidPrice = javaType.bidPrice().map({ args0 -> args0 }).orElse(null),
            bidPriceAsPercentageOfOnDemandPrice = javaType.bidPriceAsPercentageOfOnDemandPrice().map({ args0 ->
                args0
            }).orElse(null),
            configurations = javaType.configurations().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.emr.kotlin.outputs.InstanceFleetInstanceTypeConfigConfiguration.Companion.toKotlin(args0)
                })
            }),
            ebsConfigs = javaType.ebsConfigs().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.emr.kotlin.outputs.InstanceFleetInstanceTypeConfigEbsConfig.Companion.toKotlin(args0)
                })
            }),
            instanceType = javaType.instanceType(),
            weightedCapacity = javaType.weightedCapacity().map({ args0 -> args0 }).orElse(null),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/emr/kotlin/outputs/InstanceFleetInstanceTypeConfig.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.emr.kotlin.outputs

import kotlin.Double
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property bidPrice The bid price for each EC2 Spot instance type as defined by `instance_type`. Expressed in USD. If neither `bid_price` nor `bid_price_as_percentage_of_on_demand_price` is provided, `bid_price_as_percentage_of_on_demand_price` defaults to 100%.
 * @property bidPriceAsPercentageOfOnDemandPrice The bid price, as a percentage of On-Demand price, for each EC2 Spot instance as defined by `instance_type`. Expressed as a number (for example, 20 specifies 20%). If neither `bid_price` nor `bid_price_as_percentage_of_on_demand_price` is provided, `bid_price_as_percentage_of_on_demand_price` defaults to 100%.
 * @property configurations A configuration classification that applies when provisioning cluster instances, which can include configurations for applications and software that run on the cluster. List of `configuration` blocks.
 * @property ebsConfigs Configuration block(s) for EBS volumes attached to each instance in the instance group. Detailed below.
 * @property instanceType An EC2 instance type, such as m4.xlarge.
 * @property weightedCapacity The number of units that a provisioned instance of this type provides toward fulfilling the target capacities defined in `aws.emr.InstanceFleet`.
 */
public data class InstanceFleetInstanceTypeConfig(
    public val bidPrice: String? = null,
    public val bidPriceAsPercentageOfOnDemandPrice: Double? = null,
    public val configurations: List<InstanceFleetInstanceTypeConfigConfiguration>? = null,
    public val ebsConfigs: List<InstanceFleetInstanceTypeConfigEbsConfig>? = null,
    public val instanceType: String,
    public val weightedCapacity: Int? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.emr.outputs.InstanceFleetInstanceTypeConfig): InstanceFleetInstanceTypeConfig = InstanceFleetInstanceTypeConfig(
            bidPrice = javaType.bidPrice().map({ args0 -> args0 }).orElse(null),
            bidPriceAsPercentageOfOnDemandPrice = javaType.bidPriceAsPercentageOfOnDemandPrice().map({ args0 ->
                args0
            }).orElse(null),
            configurations = javaType.configurations().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.emr.kotlin.outputs.InstanceFleetInstanceTypeConfigConfiguration.Companion.toKotlin(args0)
                })
            }),
            ebsConfigs = javaType.ebsConfigs().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.emr.kotlin.outputs.InstanceFleetInstanceTypeConfigEbsConfig.Companion.toKotlin(args0)
                })
            }),
            instanceType = javaType.instanceType(),
            weightedCapacity = javaType.weightedCapacity().map({ args0 -> args0 }).orElse(null),
        )
    }
}
